Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/KhronosGroup/Vulkan-Loader.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'tests/framework/test_environment.h')
-rw-r--r--tests/framework/test_environment.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/tests/framework/test_environment.h b/tests/framework/test_environment.h
index 261b85ff6..7d2e00e74 100644
--- a/tests/framework/test_environment.h
+++ b/tests/framework/test_environment.h
@@ -492,8 +492,9 @@ enum class ManifestLocation {
};
struct FrameworkEnvironment {
- FrameworkEnvironment() noexcept; // default is to enable VK_LOADER_DEBUG=all
+ FrameworkEnvironment() noexcept; // default is to enable VK_LOADER_DEBUG=all and enable the default search paths
FrameworkEnvironment(bool enable_log) noexcept;
+ FrameworkEnvironment(bool enable_log, bool enable_default_search_paths) noexcept;
void add_icd(TestICDDetails icd_details) noexcept;
void add_implicit_layer(ManifestLayer layer_manifest, const std::string& json_name) noexcept;